@@ -1,21 +1,21 @@
-import logging
 from lettuce import before, world, after
 from splinter.browser import Browser
+from salad.logger import logger
 
 
 @before.all
 def setup_browser():
-    logging.info("Setting up firefox...")
+    logger.info("Setting up firefox...")
     try:
         world.firefox = Browser("firefox")
     except:
-        logging.warn("Error starting up firefox")
+        logger.warn("Error starting up firefox")
 
 
 @after.all
 def teardown_browser(total):
-    logging.info("Tearing down firefox...")
+    logger.info("Tearing down firefox...")
     try:
         world.firefox.quit()
     except:
-        logging.warn("Error tearing down firefox")
+        logger.warn("Error tearing down firefox")
